require 'active_record'
require 'genome-lib'

Signal.trap("TERM") do
  # Clean up any active record connections
  ActiveRecord::Base.remove_connection

  Cloudhost::VirtWatcher.stop

  # Cleanly exit
  exit 0
end

module Cloudhost
  class VirtWatcher
    include GenomeLib
     
    def initialize
      @virsh = Virsh.new
    end
    
    def collect_guests
      guests = @virsh.list(:all => true)
      $LOG.debug("Found #{guests.size} guests.")

      guests.each do |g|
        guest = Cloudhost::Models::Guest.find(:first, :conditions => "uuid = '#{g.uuid}'")
        if guest.nil?
          $LOG.debug("Creating a new guest: #{g.name}, #{g.uuid}, #{g.status}")
          Cloudhost::Models::Guest.create :name => g.name,
                       :uuid => g.uuid,
                       :status => g.status,
                       :last_updated => DateTime.now
        else
          $LOG.debug("Guest with uuid '#{g.uuid}' found.")
          # This should handle the case of a guest being renamed
          guest.name = g.name
          guest.status = g.status
          guest.last_updated = DateTime.now
          guest.save!
        end
      end
    end

    def run
      collect_guests
    end
  end
end
